Wear class abstract

Utils class with generic functionally revolving around wear

Constructors

Wear()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getNodes() Future<List<WearNode>>
listen(String path, WearMessageCallback handler) → void
removeListener(String path, WearMessageCallback handler) → void
send(WearMessage message) Future<List<int?>?>